#include <windows.h>
#include <stdio.h>
#include <conio.h>

/***********************************************/
/* DLL header								   */
/***********************************************/ 
#include "..\common\anzeige_dllloader.h"
#include "..\common\mc4self_dllloader.h"
/***********************************************/

HINSTANCE hInst_MC4SelfDll;
HINSTANCE hInst_AnzeigeDll;

/****************************************************************************/
/* Function include sample for automatic measurement	                    */
/****************************************************************************/
int demo_automatic(void)
{
	int				m_Karte_MC;
	int				m_Result;
	FlashdatenEx	m_FlashData;
	int				m_SkipLessValue				= 1;
	int				m_Differential				= 0;		
	
	// 
	int				i;
	int				result						= 0;
	int				nChannels					= 0;
	int				nADChannels					= 0;
	int				nCTChannels					= 0;
	int				nSamplratePerChannel		= 1000;
	int				nCumulateValues				= 0;
	int				nValuesPerChannel			= 0;
	int				nBlocksize					= nSamplratePerChannel/10;
	int				nAvailableValuesPerChannel	= 0;
	void*			p_ScaledBuffer				= 0;
	void*			p_BinaryBuffer				= 0;
	double*			pfValue;
	unsigned int*	pnValue;

	// Prepare 
	m_Karte_MC = -1;
	/* ******************************************************************** *
	 * find first valid device
	 * ******************************************************************** */
	for (i=0; i<16; i++) {
		if (OpenCard(i)==ERROR_SUCCESS) {
			m_Karte_MC = i;
			CloseCard(i);
		}
	}
	if (m_Karte_MC == -1)
		goto __exit;

	/* ******************************************************************** *
	 * read cardinfo
	 * ******************************************************************** */
	printf("CardInfo: \n");
	/* m_Karte_MC */
	if (OpenCard(m_Karte_MC)==MAPI_ERROR_SUCCESS)
		printf("OpenCard (%d) [ok]\n",m_Karte_MC);
	else {
		printf("OpenCard (%d) [failed]\n",m_Karte_MC);
		goto __exit;
	}
	
	memset((void*)&m_FlashData, 0, sizeof(FlashdatenEx));
	if (ReadFlashDataEx(m_Karte_MC,&m_FlashData)==MAPI_ERROR_SUCCESS) {
		printf("ReadFlashDataEx [ok]\n");
		printf("\tName\t\t: %s\n", m_FlashData.Name);
		printf("\tSerial number\t: %s\n", m_FlashData.Serial);
		printf("\tAD channels\t: %d\n", m_FlashData.AnzahlAD);
		printf("\tDA channels\t: %d\n", m_FlashData.AnzahlDA);
		printf("\tCT channels\t: %d\n", m_FlashData.AnzahlCT);
		printf("\tTTL channels\t: %d\n", m_FlashData.AnzahlTTL);
		printf("\tPWM channels\t: %d\n", m_FlashData.AnzahlPWM);
		printf("\tADC\t\t: %d bit\n", m_FlashData.BitbreiteAD*8);
		printf("\tDAC\t\t: %d bit\n", m_FlashData.BitbreiteDA*8);
		nADChannels = m_FlashData.AnzahlAD;	
		nCTChannels = m_FlashData.AnzahlCT;
	}
	else {
		printf("ReadFlashDataEx [failed]\n");
		nADChannels = 0;
		goto __exit;
	}
	
	/* ******************************************************************** *
	 * setup hardware and clear channellists
	 * ******************************************************************** */
	if (ConfigCard(m_Differential,1,1)==MAPI_ERROR_SUCCESS)
		printf("ConfigCard [ok]\n");
	else
		printf("ConfigCard [failed]\n");

	if (m_Differential) 
		nADChannels = m_FlashData.AnzahlAD >> 1;	

	if (SwitchCard(m_Karte_MC)==MAPI_ERROR_SUCCESS)
		printf("SwitchCard [ok]\n");
	else
		printf("SwitchCard [failed]\n");

	if (ClearChannelLists()==MAPI_ERROR_SUCCESS)
		printf("ClearChannellists [ok]\n");
	else
		printf("ClearChannellists [failed]\n");

	/* ******************************************************************** *
	 * initialise A/D measure
	 * ******************************************************************** */
	nChannels = 0;
	for (i=0; i<m_FlashData.AnzahlAD; i++) {
		if (Add_AD_Channel_to_ScanList(i,0,0,0) == MAPI_ERROR_SUCCESS) {
			printf("Add_AD_Channel_to_ScanList [ok] Channel %d\n", i);
			nChannels++;
		} else {
			printf("Add_AD_Channel_to_ScanList [failed] Channel %d\n", i);
			goto __exit;
		}
	}

	/* ***************************
	 * initialise CT measure
	 * ************************************************* */
	if (nChannels == 0) {
		printf("!!! The measurement device need a A/D channel as first entry in scanlist.!!!\n");
		goto __exit;
	}

	for (i=0; i<nCTChannels; i++) {
		
		if ( ConfigureCounterInput (i,													// ChannelNumber - Zhlerkanalnummer
									i>1?COUNTER_MODE_INCREMENTAL:COUNTER_MODE_PULSE,											// Countermode - Zhlermodus
																						//	0 - Impulszaehler
																						//	1 - Frequenzzaehler
																						//	2 - Periodendauerzaehler
																						//	3 - Pulsbreitenzaehler
																						//	4 - N/A
																						//	5 - Inkrementalzaehler
									0,													// PresetValue - Zhlerstartwert festlegen
									0,													// FrequencyResolution - Zhlerauflsung
									0,													// Flanke - Zhlerflanke
									1,													// InkrementalSWReset - den Inkrementalzhler beim Start der Messung lschen
									0,													// InkrementalHWReset - die Auswertzung des Resetimpulses(ausgelst von dem Inkrementalgeber) aktivieren
																						//	0 - off
																						//	1 - level triggered reset mode
																						//	2 - extended level triggered reset mode
																						//  3 - edge triggered reset mode
									0,													// InkrementalHWResetEdgeLevel - die Flanke/Level des Resetimpulses festlegen
																						//  0 - high level / rising edge
																						//  1 - low level / falling edge
									2													// InkrementalInterpolation - festlegen der Inkrementalzhlerinterpolation(1x/2x/4x) festlegen
																						//	0 - 1-fach Interpolation
																						//	1 - 2-fach Interpolation
																						//	2 - 4-fach Interpolation
									) != MAPI_ERROR_SUCCESS) {
			printf("ConfigureCounterInput [failed] Channel %d\n", i);
			goto __exit;
		}

		if (Add_CT_Channel_to_ScanList(i)==MAPI_ERROR_SUCCESS) {
			printf("Add_CT_Channel_to_ScanList [ok] Channel %d\n", i);
			nChannels++;
		} else {
			printf("Add_CT_Channel_to_ScanList [failed] Channel %d\n", i);
			goto __exit;
		}
	}

	if (SetADFrequency(nSamplratePerChannel)==MAPI_ERROR_SUCCESS)
		printf("SetADFrequency [ok]\n");
	else
		printf("SetADFrequency [failed]\n");

	if (FinalInit() == MAPI_ERROR_SUCCESS)
		printf("FinalInit [ok]\n");
	else
		printf("FinalInit [failed]\n");

	printf("Press any key to continue... \n");
	getch();

	if (StartMemoryMeasurement(m_Karte_MC,nChannels,0,nSamplratePerChannel)==MAPI_ERROR_SUCCESS)
		printf("StartMemoryMeasurement [ok]\n");
	else
		printf("StartMemoryMeasurement [failed]\n");

	/* Measureloop *************************************************/
	
	p_ScaledBuffer = malloc(nChannels * nBlocksize * sizeof(double));
	p_BinaryBuffer = malloc(nChannels * nBlocksize * sizeof(unsigned int));
	if (!p_ScaledBuffer || !p_BinaryBuffer)
		goto __exit;

	while(TRUE) 
	{
		/* ******************************************************************** *
		 * Manueller Abbruch <ESC>
		 * ******************************************************************** */
		if(kbhit()) if (getch()==27) break;

		/* ******************************************************************** *
		 * Aktuellen Fifofuellstand ermitteln
		 * ******************************************************************** */
		nAvailableValuesPerChannel = 0;
		result = GetMemoryMeasurementStatus(m_Karte_MC);

	//	if (!MC4SELF_ErrorSuccess(result,1)) break;
#if 0
		result = GetBufferStatus(&nAvailableValuesPerChannel);

		//if (!MC4SELF_SUCCESS(result)) break;
		if (!MC4SELF_ErrorSuccess(result,1)) break;
		
		if (nAvailableValuesPerChannel < nBlocksize) {							// Anzahl der im Fifo verfuegbaren Werte kleiner der vorparametrierten 
																				// Blockgroee
			if (!m_SkipLessValue) {												// 
				nValuesPerADChannel = nAvailableValuesPerChannel;
			} else {
				SleepEx(3,FALSE);												// CPU Zeit freigeben
				continue;														// Auf die entsprechende Anzahl an erfassten Werten warten
			}
		} else {
			nValuesPerADChannel = nBlocksize;									// Transferwerte mit den verfuegbaren Zwischenpuffergroeen 
		}
#endif

		/* ******************************************************************** *
		 * Messwerte abholen und verarbeiten
		 * ******************************************************************** */
		result = GetScaledDataFromMemoryMeasurement(m_Karte_MC,					// cardid
													0,							// scaling mode
													nChannels,					// number of channels (burst length)
													nBlocksize,					// number of values per channel (blocksize)
					     							p_ScaledBuffer,				// destination data pointer (double)
													m_SkipLessValue,			// block mode
													&nValuesPerChannel);		// number of values per channel in destination data array

		if (!MC4SELF_ErrorSuccess(result,1)) break;

		if (nValuesPerChannel > 0) {
			pfValue = (double*)p_ScaledBuffer;
			system("CLS");
			printf("Press [ESC] for exit... \n");
			printf("Samplerate\t\t: %d\n",nADChannels * nSamplratePerChannel);
			printf("Samplerate per channel\t: %d\n",nSamplratePerChannel);
			printf("Values per channel\t: %d\n",nBlocksize);
			printf("Number of Values\t: %d (%d)", nCumulateValues, result);
			for (i=0; i<nChannels; i++) {
				if ((i % 8) == 0) {
					printf("\n");
					printf("K%02d-%02d: ",i,i+7);
				}
				printf("%2.2f " , *pfValue++);
			}
			nCumulateValues += nValuesPerChannel;
		}
	}
	printf("\n");
		
	if (StopMemoryMeasurement(m_Karte_MC)==MAPI_ERROR_SUCCESS)
		printf("StopMemoryMeasurement [ok]\n");
	else
		printf("StopMemoryMeasurement [failed]\n");
	
	if (DeInitMemoryMeasurement(m_Karte_MC)==MAPI_ERROR_SUCCESS)
		printf("DeInitMemoryMeasurement [ok]\n");
	else
		printf("DeInitMemoryMeasurement [failed]\n");
__exit:
	if (p_ScaledBuffer)
		free(p_ScaledBuffer);
	if (p_BinaryBuffer)
		free(p_BinaryBuffer);

	if (CloseCard(m_Karte_MC)==MAPI_ERROR_SUCCESS)
		printf("CloseCard (%d) [ok]\n",m_Karte_MC);
	else
		printf("CloseCard (%d) [failed], card already closed\n",m_Karte_MC);
	
	return 0;
}

int main(void)
{
	int selection;
	int key;

	if ( (hInst_MC4SelfDll = MC4SELF_LoadLibrary()) == NULL) {
		system("PAUSE");
		exit(0);
	}


	selection = 'a';
	while (1) {
		system("CLS");
		printf("\n");
		printf("Multichoice USB AD Measurement Demo Application\n");
		printf("\n");
		printf("\n\nPress enter to start measure....\n");
		key = getch();
		switch(key)
		{
		case 13: // <ENTER>
			demo_automatic();
		case 27: // <ESC>
			MC4SELF_FreeLibrary(hInst_MC4SelfDll);

			printf("\n\nPress any key to exit....\n");
			getch();
			return 0;
			break;
		}
	}

	return 0;
}
