/*******************************************************************************/
/* Function: dynamic MC4Self.DLL Loader 
/*			 Goldammer GmbH (C) 2005
/*
/* Date		  Dev						Comment
/* ----------------------------------------------------------------------------*/
/* 09.06.2005 Torsten Schinkel			Init Release
/*
/*
/*******************************************************************************/

#include <windows.h>
#include <stdio.h>

#ifndef _MC4SELF_DLLLOADER_H
#define _MC4SELF_DLLLOADER_H

// Schalter fr Dunamisches/Statisches Laden
#define LoadDynamically
//#undef LoadDynamically


HINSTANCE	MC4SELF_LoadLibrary(void);
BOOL		MC4SELF_FreeLibrary(HINSTANCE hInst);
BOOL		MC4SELF_ErrorSuccess(int nResult, int nPrintErrorMessage = 0);

#define		MC4SELF_SUCCESS(x)					MC4SELF_ErrorSuccess(x,0)

#define		MAPI_ERROR_SUCCESS					0
#define		MAPI_ERROR_UNSUCCESSFUL				1
#define		MAPI_ERROR_PARAMETER				2
#define		MAPI_ERROR_OVERFLOW					3
#define		MAPI_ERROR_INVALIDCARD				4
#define		MAPI_ERROR_FINISHED					10
#define		MAPI_ERROR_INACTIVE					11
#define		MAPI_ERROR_RUNNING					12
#define		MAPI_ERROR_OVERFLOW_INTERNAL		33

// Counter
#define		COUNTER_MODE_PULSE					0
#define		COUNTER_MODE_FREQUENCY				1
#define		COUNTER_MODE_CYCLEDURATION			2
#define		COUNTER_MODE_PULSEWIDTH				3
#define		COUNTER_MODE_INCREMENTAL			5

// Counter - physical channel number 
#define		COUNTER_T0_CHANNEL					0					// universal counter 0
#define		COUNTER_T1_CHANNEL					1					// universal counter 1

#define		COUNTER_INC0I_CHANNEL				2					// incremental counter 0 - number of triggered increments	
#define		COUNTER_INC0T_CHANNEL				3					// incremental counter 0 - timestamp of last triggered increment
#define		COUNTER_INC1I_CHANNEL				4					// incremental counter 1 - number of triggered increments	
#define		COUNTER_INC1T_CHANNEL				5					// incremental counter 1 - timestamp of last triggered increment

typedef struct
{ 
  char Name[32];
  char Serial[20];
  int AnzahlAD;
  int BitbreiteAD;
  int AnzahlDA;
  int BitbreiteDA;
  int AnzahlCT;
  int AnzahlTTL;
  int PortbreiteTTL;
  int AnzahlPWM;
} Flashdaten, *PFlashdaten;

typedef struct
{
	int LowBorder;
	int HighBorder;
} ESP;

typedef struct
{ 
  char Name[32];
  char Serial[20];
  int AnzahlAD;
  int BitbreiteAD;
  int AnzahlDA;
  int BitbreiteDA;
  int AnzahlCT;
  int AnzahlTTL;
  int PortbreiteTTL;
  int AnzahlPWM;
  int SE_Possible;
  int SE_Summe;
  int Dif_Possible;
  int Dif_Summe;
  int NumOfESB;
  ESP Eingangsbereiche[10];
  int NumOfGain;
  int Gain[4];
  int TaktBasis;
} FlashdatenEx, *PFlashdatenEx;

typedef struct 
{
	int USBWDM;
	int ReservedForFutureUse[7];
} EnhancedInformations, *PEnhancedInformations;

typedef struct
{
	int ICP;
	int AC;
	int Gain;
	int SE;
} ICPStruct, *PICPStruct;

#ifdef LoadDynamically
/*******************************************************************************/
/* Externe Funktionsprototypen   												       */
/*******************************************************************************/
//-Main-------------------------------------------------------------------
extern int (__stdcall	*LoadCard)							(int CardID);
extern int (__stdcall	*OpenCard)							(int CardID);
extern int (__stdcall	*CloseCard)							(int CardID);
extern int (__stdcall	*SwitchCard)						(int CardID);

extern int (__stdcall   *ReadFlashData)						(int CardID, void* BufferPtr);
extern int (__stdcall   *ReadFlashDataEx)					(int CardID, void* BufferPtr);
extern int (__stdcall   *GetEnhancedInformations)			(int CardID, PEnhancedInformations DestinationPointer);
extern int (__stdcall   *ConfigCard)						(int Differenzmodus, int ADWandler, int DARange);

extern int (__stdcall   *CaptureOneChannel)					(int ChannelNumber, int Differenzmodus, int InputRange, void* ScaledValue, void* BinaryValue);
extern int (__stdcall   *CaptureOneChannelEx)				(int ChannelNumber, int Differenzmodus, int InputRange, int Gain, int Oversampling, int Bipolar,  double* ScaledValue, int* BinaryValue);
extern int (__stdcall   *ClearChannelLists)					(void);
extern int (__stdcall   *ClearChannelListsEx)				(int CardID, int SWTakt, int SWSignalisierung);
extern int (__stdcall   *PrepareFilterEntry)				(int Channel, int Filtermode, int SampleFreq, 
															 double Freq1, double Freq2,
															 double Freq3, double Freq4,
															 double Passabsorption, double Stopbandattenuation,
															 int MaxOrder, 
															 int DesignMethod, 
															 int Filtertyp,
															 int Window, 
															 int Param1);
//-AD---------------------------------------------------------------------
extern  int (__stdcall   *Add_AD_Channel_to_ScanList)		(int ChannelNumber, int Oversampling, int Gain, int Bipolar);
extern  int (__stdcall   *Add_Dig_Channel_to_ScanList)		(int ChannelNumber, int Typ);
extern  int (__stdcall   *Add_CT_Channel_to_ScanList)		(int ChannelNumber);
extern  int (__stdcall   *SetADFrequency)					(int FrequencyPerChannel);
extern  int (__stdcall   *SetADFrequencyEx)					(int FrequencyPerChannel, double* ReelleFrequenz, int* Basisfrequenz);
extern  int (__stdcall	 *SetADConvertDelay)				(int nConvertDelay);
extern  int (__stdcall   *FinalInit)						(void);
extern  int (__stdcall   *StartADCapture)					(void);
extern  int (__stdcall   *StartADCaptureEx)					(int ExtDigTrigger, int ExtDigTakt, int ExtDigFlanke);
extern  int (__stdcall   *StopADCapture)					(void);
extern  int (__stdcall   *GetScaledData)					(int InputRange, void* DestinationBuffer, void* NumberPerChannel, int SkipLessData);
extern  int (__stdcall   *GetBinaryData)					(void* DestinationBuffer, void* NumberPerChannel, int SkipLessData);
extern  int (__stdcall	 *GetBufferStatus)					(void* ValuesPerChannel);
//-DA---------------------------------------------------------------------
extern  int (__stdcall   *PutOneChannel)					(int ChannelNumber, int OutputRange, double ScaledValue);
extern  int (__stdcall   *Add_DA_Channel_to_ScanList)		(int ChannelNumber);
extern  int (__stdcall   *Add_DA_Channel_to_ScanListEx)		(int ChannelNumber, int Buffertype, int BufferSize);
extern  int (__stdcall   *SetDAFrequency)					(int FrequencyPerChannel);
extern  int (__stdcall   *StartDAOutput)					(void);
extern  int (__stdcall   *StartDAOutputEx)					(int ExtDigTrigger, int ExtDigTakt, int ExtDigFlanke);
extern  int (__stdcall   *StopDAOutput)						(void);
extern  int (__stdcall   *PutScaledData)					(int OutputRange, void* SourceBuffer, int NumberOfChannels, void* NumberPerChannel, int SkipLessData);
extern  int (__stdcall   *PutBinaryData)					(void* SourceBuffer, int NumberOfChannels, void* NumberPerChannel, int SkipLessData);
extern  int (__stdcall   *GetBufferSpace)					(void* FreeWordsPerChannel);
//-DIO--------------------------------------------------------------------
extern  int (__stdcall   *SetDigitalDirection)				(int Channel, int Direction);
extern  int (__stdcall   *ReadDigitalBit)					(int Channel, void* Value);
extern  int (__stdcall   *WriteDigitalBit)					(int Channel, int Value);
extern  int (__stdcall   *SetDigitalPortDirection)			(int StartChannel, int Bits, int Direction);
extern  int (__stdcall   *ReadDigitalPort)					(int StartChannel, int Bits, int* Value);
extern  int (__stdcall   *WriteDigitalPort)					(int StartChannel, int Bits, int Value);

extern  int (__stdcall   *DIN_AddChannel_To_DINScanlist)	(int ChannelNumber, int Typ);
extern  int (__stdcall   *SetDINFrequency)					(double Frequency);
extern  int (__stdcall   *StartDINCapture)					();
extern  int (__stdcall   *StartDINCaptureEx)				(int ExtDigTrigger, int ExtDigTakt, int ExtDigFlanke);
extern  int (__stdcall   *StopDINCapture)					();
extern  int (__stdcall   *DIN_GetBinaryData)				(int Channel, void* DestinationBuffer, void* NumberPerChannel, int SkipLessData);
extern  int (__stdcall   *DIN_GetScaledData)				(int Channel, void* DestinationBuffer, void* NumberPerChannel, int SkipLessData);
extern  int (__stdcall   *GetDINBufferStatus)				(int CardID, void* SampledValuesPerChannel);
//-CT---------------------------------------------------------------------
extern  int (__stdcall   *ConfigureCounterInput)			(int ChannelNumber, 
															 int Countermode, 
															 int PresetValue,
															 int FrequencyResolution,
															 int Flanke,
															 int InkrementalSWReset, 
															 int InkrementalHWReset,
															 int InkrementalHWResetFlanke, 
															 int InkrementalInterpolation );
extern  int (__stdcall   *ReadCounterValue)					(int ChannelNumber, void* Value);

extern  int (__stdcall   *CT_AddChannel_To_CTScanlist)		(int Channel);
extern  int (__stdcall   *SetCTFrequency)					(double Frequency);
extern  int (__stdcall   *StartCTCapture)					();
extern  int (__stdcall   *StartCTCaptureEx)					(int ExtDigTrigger, int ExtDigTakt, int ExtDigFlanke);
extern  int (__stdcall   *StopCTCapture)					();
extern  int (__stdcall   *CT_GetScaledData)					(void* DestinationBuffer, void* NumberPerChannel, int SkipLessData);
extern  int (__stdcall   *CT_GetBufferStatus)				(void* SampledValuesPerChannel);
//-PWM--------------------------------------------------------------------
extern  int (__stdcall   *PreparePWMOutput)					(int ChannelNumber, int BaseFrequency, int StartRatio);
extern  int (__stdcall   *PrepareFMOutput)					(int ChannelNumber, int StartFrequency, int PulsWidthRatio);
extern  int (__stdcall   *WriteNewPWMRatio)					(int ChannelNumber, int BaseFrequency, int Ratio);
extern  int (__stdcall   *WriteNewFMRatio)					(int ChannelNumber, int Frequency, int PWRatio);
//-MM---------------------------------------------------------------------
extern  int (__stdcall   *StartMemoryMeasurement)			(int CardID, int AnzahlKanaele, int ValuesPerChannel, int FrequencyPerChannel);
extern  int (__stdcall   *StartMemoryMeasurementEx)			(int CardID, int AnzahlKanaele, int ValuesPerChannel, int FrequencyPerChannel, int UsualBlockSize);
extern  int (__stdcall   *PrepareExtTrigger)				(int CardID, int ExtDigTrigger, int ExtDigTakt, int ExtDigFlanke);
extern  int (__stdcall	 *StopMemoryMeasurement)			(int CardID);
extern	int	(__stdcall	 *DeInitMemoryMeasurement)			(int CardID);
extern  int (__stdcall	 *ReadMemoryMeasurement)			(int CardID, int* UsedValues, int* FIFOSize);
extern  int (__stdcall	 *GetMemoryMeasurementStatus)	    (int CardID);
extern  int (__stdcall	 *GetScaledDataFromMemoryMeasurement)(int CardID,
															 int InputRange,
															 int AnzahlKanaele,
															 int ValuesPerChannel,
															 void* Destination,
															 int SkipIfLessData,
															 int* TransferedWords);
extern  int (__stdcall	 *GetBinaryDataFromMemoryMeasurement)(int CardID,
															 int AnzahlKanaele,
															 int ValuesPerChannel,
															 void* Destination,
															 int SkipIfLessData,
															 int* TransferedWords);
//-Trigger----------------------------------------------------------------
extern  int (__stdcall   *PrepareTriggerEntry)				(int Channel,
															 // Starttrigger
															 int StartTriggerAktiv,
															 double StartTriggerSchwelle1,
															 double StartTriggerSchwelle2,
			  												 int StartTriggerTyp,
															 int StartTriggerAbStart,
															 int StartTriggerMessung,
															 int StartTriggerSetTTL,
															 int StartTriggerTTLKlemme,
															 int StartTriggerTTLStartzustand,
															 int StartTriggerTTLFlanke,
															 // Stoptrigger
															 int StopTriggerAktiv,
															 double StopTriggerSchwelle1,
															 double StopTriggerSchwelle2,
															 int StopTriggerTyp,
															 int StopTriggerAbStart,
															 int StopTriggerMessung,
															 int StopTriggerSetTTL,
															 int StopTriggerTTLKlemme,
															 int StopTriggerTTLStartzustand,
															 int StopTriggerTTLFlanke,
															 // Generell
															 int Retriggerbar);
extern  int (__stdcall   *PrepareTriggerTakt)				(int Channel, int AnzahlWerteProTakt, double Schwellwert, int Schwellenart);
extern  int (__stdcall	 *SetGlobalTriggerValues)			(int PreTrigger, int PostTrigger, int WaitForStartTrigger);
//-OnlineF----------------------------------------------------------------
extern  int (__stdcall   *PrepareFFTEntry)					(int Channel, 
															 int AnzahlPunkte, 
															 int Spektrum, 
															 double Gain,
															 int Fensterfunktion, 
															 double Parameter);
extern  int (__stdcall   *PreparePIDEntry)					(int Channel,
															 double PAnteil,
															 double IAnteil,
															 double  DAnteil,
															 int  Reglerart,
															 double Gain,
															 double Sollwert,
															 double MinValue,
															 double MaxValue,
															 int  DAKanal,
															 int SampleFreq);
extern  int (__stdcall   *GetFFTData)						(int KanalNrInListe, void* DestinationBuffer);
extern  int (__stdcall   *GetDLLVersion)					(char *VString, int* V1, int* V2, int* V3);

extern  int (__stdcall   *ProgramUserTimerFrequency)		(int CardID, int Delay_in_ms);
extern  int (__stdcall   *StartUserTimer)					(int CardID, int EventHandle);
extern  int (__stdcall   *StopUserTimer)					(int CardID);
extern  int (__stdcall   *ShowDebugNumber)					(int Number);

extern	int	(__stdcall	 *SendICPSettings)					(int CardID, void* ICPSettings);

extern	int (__stdcall	 *GetHWExtensions)					(int CardID);
extern	int (__stdcall	 *GetSWExtensions)					(int CardID);

extern  int (__stdcall	 *GetCTBufferStatus)				(int CardID, void* ValuesPerChannel);
extern  int (__stdcall	 *GetADBufferStatus)				(int CardID, void* ValuesPerChannel);
extern  int (__stdcall	 *GetDAFreeBufferSpace)				(int CardID, void* FreeValuesPerChannel);

#else //LoadDynamically

#define DllImport __declspec( dllimport ) __stdcall
/*******************************************************************************/
/* Externe Funktionsprototypen   												       */
/*******************************************************************************/
//-Main-------------------------------------------------------------------
extern "C" int DllImport LoadCard (int CardID);
extern "C" int DllImport OpenCard (int CardID);
extern "C" int DllImport CloseCard (int CardID);
extern "C" int DllImport SwitchCard	(int CardID);

extern "C" int DllImport ReadFlashData (int CardNr, void* BufferPtr);
extern "C" int DllImport ReadFlashDataEx (int CardNr, void* BufferPtr);
extern "C" int DllImport GetEnhancedInformations (int CardNr, PEnhancedInformations DestinationPointer);
extern "C" int DllImport ConfigCard (int Differenzmodus, int ADWandler, int DARange);

extern "C" int DllImport CaptureOneChannel (int ChannelNumber, int Differenzmodus, int InputRange, void* ScaledValue, void* BinaryValue);
extern "C" int DllImport CaptureOneChannelEx (int ChannelNumber, int Differenzmodus, int InputRange, int Gain, int Oversampling, int Bipolar,  double* ScaledValue, int* BinaryValue);
extern "C" int DllImport ClearChannelLists (void);
extern "C" int DllImport ClearChannelListsEx (int CardNr, int SWTakt, int SWSignalisierung);
extern "C" int DllImport PrepareFilterEntry	(int Channel, int Filtermode, int SampleFreq, 
															 double Freq1, double Freq2,
															 double Freq3, double Freq4,
															 double Passabsorption, double Stopbandattenuation,
															 int MaxOrder, 
															 int DesignMethod, 
															 int Filtertyp,
															 int Window, 
															 int Param1);
//-AD---------------------------------------------------------------------
extern "C" int DllImport Add_AD_Channel_to_ScanList (int ChannelNumber, int Oversampling, int Gain, int Bipolar);
extern "C" int DllImport Add_Dig_Channel_to_ScanList (int ChannelNumber, int Typ);
extern "C" int DllImport Add_CT_Channel_to_ScanList (int ChannelNumber);
extern "C" int DllImport SetADFrequency (int FrequencyPerChannel);
extern "C" int DllImport SetADFrequencyEx (int FrequencyPerChannel, double* ReelleFrequenz, int* Basisfrequenz);
extern "C" int DllImport FinalInit (void);
extern "C" int DllImport StartADCapture (void);
extern "C" int DllImport StartADCaptureEx (int ExtDigTrigger, int ExtDigTakt, int ExtDigFlanke);
extern "C" int DllImport StopADCapture (void);
extern "C" int DllImport GetScaledData (int InputRange, void* DestinationBuffer, void* NumberPerChannel, int SkipLessData);
extern "C" int DllImport GetBinaryData (void* DestinationBuffer, void* NumberPerChannel, int SkipLessData);
extern "C" int DllImport GetBufferStatus (void* ValuesPerChannel);
//-DA---------------------------------------------------------------------
extern "C" int DllImport PutOneChannel (int ChannelNumber, int OutputRange, double ScaledValue);
extern "C" int DllImport Add_DA_Channel_to_ScanList (int ChannelNumber);
extern "C" int DllImport Add_DA_Channel_to_ScanListEx (int ChannelNumber, int Buffertype, int BufferSize);
extern "C" int DllImport SetDAFrequency (int FrequencyPerChannel);
extern "C" int DllImport StartDAOutput (void);
extern "C" int DllImport StartDAOutputEx (int ExtDigTrigger, int ExtDigTakt, int ExtDigFlanke);
extern "C" int DllImport StopDAOutput (void);
extern "C" int DllImport PutScaledData (int OutputRange, void* SourceBuffer, int NumberOfChannels, void* NumberPerChannel, int SkipLessData);
extern "C" int DllImport PutBinaryData (void* SourceBuffer, int NumberOfChannels, void* NumberPerChannel, int SkipLessData);
extern "C" int DllImport GetBufferSpace (void* FreeWordsPerChannel);
//-DIO--------------------------------------------------------------------
extern "C" int DllImport SetDigitalDirection (int Channel, int Direction);
extern "C" int DllImport ReadDigitalBit (int Channel, void* Value);
extern "C" int DllImport WriteDigitalBit (int Channel, int Value);
extern "C" int DllImport SetDigitalPortDirection (int StartChannel, int Bits, int Direction);
extern "C" int DllImport ReadDigitalPort (int StartChannel, int Bits, int* Value);
extern "C" int DllImport WriteDigitalPort (int StartChannel, int Bits, int Value);

extern "C" int DllImport DIN_AddChannel_To_DINScanlist (int ChannelNumber, int Typ);
extern "C" int DllImport SetDINFrequency (double Frequency);
extern "C" int DllImport StartDINCapture ();
extern "C" int DllImport StartDINCaptureEx (int ExtDigTrigger, int ExtDigTakt, int ExtDigFlanke);
extern "C" int DllImport StopDINCapture ();
extern "C" int DllImport DIN_GetBinaryData (int Channel, void* DestinationBuffer, void* NumberPerChannel, int SkipLessData);
extern "C" int DllImport DIN_GetScaledData (int Channel, void* DestinationBuffer, void* NumberPerChannel, int SkipLessData);
extern "C" int DllImport GetDINBufferStatus	(int CardID, void* SampledValuesPerChannel);
//-CT---------------------------------------------------------------------
extern "C" int DllImport ConfigureCounterInput (int ChannelNumber, 
															 int Countermode, 
															 int PresetValue,
															 int FrequencyResolution,
															 int Flanke,
															 int InkrementalSWReset, 
															 int InkrementalHWReset,
															 int InkrementalHWResetFlanke, 
															 int InkrementalInterpolation );
extern "C" int DllImport ReadCounterValue (int ChannelNumber, void* Value);

extern "C" int DllImport CT_AddChannel_To_CTScanlist (int Channel);
extern "C" int DllImport SetCTFrequency (double Frequency);
extern "C" int DllImport StartCTCapture ();
extern "C" int DllImport StartCTCaptureEx (int ExtDigTrigger, int ExtDigTakt, int ExtDigFlanke);
extern "C" int DllImport StopCTCapture ();
extern "C" int DllImport CT_GetScaledData (void* DestinationBuffer, void* NumberPerChannel, int SkipLessData);
extern "C" int DllImport CT_GetBufferStatus (void* ValuesPerChannel);
//-PWM--------------------------------------------------------------------
extern "C" int DllImport PreparePWMOutput (int ChannelNumber, int BaseFrequency, int StartRatio);
extern "C" int DllImport PrepareFMOutput (int ChannelNumber, int StartFrequency, int PulsWidthRatio);
extern "C" int DllImport WriteNewPWMRatio (int ChannelNumber, int BaseFrequency, int Ratio);
extern "C" int DllImport WriteNewFMRatio (int ChannelNumber, int Frequency, int PWRatio);
//-MM---------------------------------------------------------------------
extern "C" int DllImport StartMemoryMeasurement (int CardID, int AnzahlKanaele, int ValuesPerChannel, int FrequencyPerChannel);
extern "C" int DllImport StartMemoryMeasurementEx (int CardID, int AnzahlKanaele, int ValuesPerChannel, int FrequencyPerChannel, int UsualBlockSize);
extern "C" int DllImport PrepareExtTrigger (int CardID, int ExtDigTrigger, int ExtDigTakt, int ExtDigFlanke);
extern "C" int DllImport StopMemoryMeasurement (int CardID);
extern "C" int DllImport DeInitMemoryMeasurement (int CardID);
extern "C" int DllImport ReadMemoryMeasurement (int CardID, int* UsedValues, int* FIFOSize);
extern "C" int DllImport GetMemoryMeasurementStatus (int CardID);
extern "C" int DllImport GetScaledDataFromMemoryMeasurement (int CardID,
															 int InputRange,
															 int AnzahlKanaele,
															 int ValuesPerChannel,
															 void* Destination,
															 int SkipIfLessData,
															 int* TransferedWords);
extern "C" int DllImport GetBinaryDataFromMemoryMeasurement (int CardID,
															 int AnzahlKanaele,
															 int ValuesPerChannel,
															 void* Destination,
															 int SkipIfLessData,
															 int* TransferedWords);
//-Trigger----------------------------------------------------------------
extern "C" int DllImport PrepareTriggerEntry (int Channel,
															 // Starttrigger
															 int StartTriggerAktiv,
															 double StartTriggerSchwelle1,
															 double StartTriggerSchwelle2,
			  												 int StartTriggerTyp,
															 int StartTriggerAbStart,
															 int StartTriggerMessung,
															 int StartTriggerSetTTL,
															 int StartTriggerTTLKlemme,
															 int StartTriggerTTLStartzustand,
															 int StartTriggerTTLFlanke,
															 // Stoptrigger
															 int StopTriggerAktiv,
															 double StopTriggerSchwelle1,
															 double StopTriggerSchwelle2,
															 int StopTriggerTyp,
															 int StopTriggerAbStart,
															 int StopTriggerMessung,
															 int StopTriggerSetTTL,
															 int StopTriggerTTLKlemme,
															 int StopTriggerTTLStartzustand,
															 int StopTriggerTTLFlanke,
															 // Generell
															 int Retriggerbar);
extern "C" int DllImport PrepareTriggerTakt (int Channel, int AnzahlWerteProTakt, double Schwellwert, int Schwellenart);
extern "C" int DllImport SetGlobalTriggerValues				(int PreTrigger, int PostTrigger, int WaitForStartTrigger);
//-OnlineF----------------------------------------------------------------
extern "C" int DllImport PrepareFFTEntry (int Channel, 
															 int AnzahlPunkte, 
															 int Spektrum, 
															 double Gain,
															 int Fensterfunktion, 
															 double Parameter);
extern "C" int DllImport PreparePIDEntry (int Channel,
															 double PAnteil,
															 double IAnteil,
															 double  DAnteil,
															 int  Reglerart,
															 double Gain,
															 double Sollwert,
															 double MinValue,
															 double MaxValue,
															 int  DAKanal,
															 int SampleFreq);
extern "C" int DllImport GetFFTData    (int KanalNrInListe, void* DestinationBuffer);
extern "C" int DllImport GetDLLVersion (char *VString, int* V1, int* V2, int* V3);
extern "C" int DllImport SendICPSettings (int CardID, void* ICPSettings);

extern "C" int DllImport GetADBufferStatus	  (int CardID, void* SampledValuesPerChannel);
extern "C" int DllImport GetCTBufferStatus	  (int CardID, void* SampledValuesPerChannel);
extern "C" int DllImport GetDAFreeBufferSpace (int CardID, void* FreeWordsPerChannel);

extern "C" int DllImport ProgramUserTimerFrequency (int CardID, int Delay_in_ms);
extern "C" int DllImport StartUserTimer (int CardID, int EventHandle);
extern "C" int DllImport StopUserTimer	(int CardID);
extern "C" int DllImport ShowDebugNumber(int Number);
#endif //LoadDynamically


#endif // _MC4SELF_DLLLOADER_H
